@@ -77,7 +77,13 @@ pin_newer_runtime_libs ()
     fi
 
     # First, grab the list of system libraries from ldconfig and put them in the arrays
-    mapfile -t ldconfig_output_array < <(/sbin/ldconfig -XNv 2> /dev/null)
+    shopt -s lastpipe
+    if /sbin/ldconfig -XNv 2> /dev/null | mapfile -t ldconfig_output_array; then
+        true  # OK
+    else
+        >&2 echo "Warning: An unexpected error occurred while executing \"/sbin/ldconfig -XNv\", the exit status was $?"
+    fi
+
     ldconfig_num=${#ldconfig_output_array[@]}
     n_done=0
 
@@ -178,14 +184,14 @@ pin_newer_runtime_libs ()
         # If we had entries in our arrays, get them
         if [[ $(file -L "$final_library") == *"32-bit"* ]]
         then
-            if [ ! -z "${host_libraries_32[$soname]+isset}" ]
+            if [ -n "${host_libraries_32[$soname]+isset}" ]
             then
                 host_soname_symlink=${host_libraries_32[$soname]}
             fi
             bitness="32"
         elif [[ $(file -L "$final_library") == *"64-bit"* ]]
         then
-            if [ ! -z "${host_libraries_64[$soname]+isset}" ]
+            if [ -n "${host_libraries_64[$soname]+isset}" ]
             then
                 host_soname_symlink=${host_libraries_64[$soname]}
             fi
