@@ -19,7 +19,7 @@ ARCHIVE_EXT=tar.xz
 # directory lives - and all this in a subshell, so we don't affect
 # $PWD
 
-STEAMROOT="$(cd $(dirname $0) && echo $PWD)"
+STEAMROOT="$(cd "$(dirname "$0")" && echo $PWD)"
 if [ -z ${STEAMROOT} ]; then
 	echo $"Couldn't find Steam root directory from "$0", aborting!"
 	exit 1
@@ -683,7 +683,7 @@ if [ "$STEAM_RUNTIME" -a "$STEAM_RUNTIME" != "0" ]; then
 		fi
 		export STEAM_RUNTIME_LIBRARY_PATH="$("$STEAM_RUNTIME/run.sh" --print-steam-runtime-library-paths)"
 
-		export LD_LIBRARY_PATH="$STEAM_RUNTIME_LIBRARY_PATH:${LD_LIBRARY_PATH-}"
+		export LD_LIBRARY_PATH="$STEAM_RUNTIME_LIBRARY_PATH"
 	else
 		echo "Unpack runtime failed, error code $?"
 		show_message --error $"Couldn't set up the Steam Runtime. Are you running low on disk space?\nContinuing..."
@@ -734,6 +734,15 @@ if [ "$STEAM_DEBUGGER" == "gdb" ] || [ "$STEAM_DEBUGGER" == "cgdb" ]; then
 		unset LD_PRELOAD
 	fi
 
+	# Ditto with LD_LIBRARY_PATH, avoids this below:
+	# gdb: /home/plagman/src/valve/Steam/main/client/ubuntu12_32/steam-runtime/pinned_libs_64/libcurl.so.4: version `CURL_OPENSSL_4' not found (required by /usr/lib/libdebuginfod.so.1)
+	: "${LD_LIBRARY_PATH=}"
+	if [ "$LD_LIBRARY_PATH" ]; then
+		echo set env LD_LIBRARY_PATH=$LD_LIBRARY_PATH >> "$ARGSFILE"
+		echo show env LD_LIBRARY_PATH >> "$ARGSFILE"
+		unset LD_LIBRARY_PATH
+	fi
+
 	echo $STEAM_DEBUGGER -x "$ARGSFILE" --args "$STEAMROOT/$STEAMEXEPATH" "$@"
 	$STEAM_DEBUGGER -x "$ARGSFILE" --args "$STEAMROOT/$STEAMEXEPATH" "$@"
 	rm "$ARGSFILE"
